package com.cmx.wanhui.activity;

import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.RequiresApi;

import com.cmx.wanhui.databinding.ActivityLoginBinding;
import com.cmx.wanhui.model.LoginBean;
import com.cmx.wanhui.model.LoginRes;
import com.cmx.wanhui.retrofit.RetrofitAPIManager;
import com.cmx.wanhui.utils.MyUtils;
import com.cmx.wanhui.utils.SpUtils;

import es.dmoral.toasty.Toasty;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class LoginActivity extends BaseActivity {

    private ActivityLoginBinding binding;

    @RequiresApi(api = Build.VERSION_CODES.M)
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ActivityLoginBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
        MyUtils.setFullscreen(this, true, true);
        MyUtils.setAndroidNativeLightStatusBar(this, true);
        binding.btnLogin.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (TextUtils.isEmpty(binding.edtUsername.getText().toString().trim())) {
                    Toasty.info(LoginActivity.this, "请输入用户名").show();
                    return;
                }
                if (TextUtils.isEmpty(binding.edtPassword.getText().toString().trim())) {
                    Toasty.info(LoginActivity.this, "请输入密码").show();
                    return;
                }
                toLogin();
            }
        });
    }


    /**
     * 登录
     */
    private void toLogin() {
        showDialog();
        LoginBean LoginBean = new LoginBean();
        LoginBean.setUsername(binding.edtUsername.getText().toString().trim());
        LoginBean.setPassword(binding.edtPassword.getText().toString().trim());
        Call<LoginRes> call = RetrofitAPIManager.provideClientApi().login(LoginBean);
        call.enqueue(new Callback<LoginRes>() {
            @Override
            public void onResponse(Call<LoginRes> call, Response<LoginRes> response) {
                disDialog();
                if (response.isSuccessful() && response.body().getCode() == 0) {
                    SpUtils.putString(LoginActivity.this, "token", response.body().getAccess_token());
                    SpUtils.putString(LoginActivity.this, "admin", response.body().getIs_admin());
                    Intent intent = new Intent(LoginActivity.this, MainActivity.class);
                    startActivity(intent);
                    finish();
                } else {
                    Toasty.error(LoginActivity.this, response.body().getMessage()).show();
                }
            }

            @Override
            public void onFailure(Call<LoginRes> call, Throwable t) {
                disDialog();
                Toasty.info(LoginActivity.this, "登录失败").show();
            }
        });
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        binding = null;
    }

}