package com.cmx.wanhui.activity;

import android.app.Activity;
import android.content.ClipData;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.util.Log;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebView;

import androidx.annotation.Nullable;

import com.cmx.wanhui.databinding.ActivityWebBinding;
import com.cmx.wanhui.utils.AndroidtoJs;
import com.cmx.wanhui.utils.L;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;


public class WebActivity extends BaseActivity {

    private WebView mWebView;
    private ActivityWebBinding binding;
    private String url;
    public static final int REQUEST_CODE_LIVENESS = 209;
    public static final int TRUST_LEVEL = 50;
    private ValueCallback<Uri[]> mUploadMessage;
    private String mCameraPhotoPath = null;
    private long size = 0;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ActivityWebBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
        url = getIntent().getStringExtra("url");
        //        MyUtils.setFullscreen(this, true, true);//影响键盘 模式 页面遮挡
        //        MyUtils.setAndroidNativeLightStatusBar(this, true);//影响键盘 模式 页面遮挡
        mWebView = binding.wvRegister;
        WebSettings webSettings = mWebView.getSettings();
        webSettings.setJavaScriptEnabled(true);
        webSettings.setCacheMode(WebSettings.LOAD_CACHE_ELSE_NETWORK);
        webSettings.setDomStorageEnabled(true);
        mWebView.addJavascriptInterface(new AndroidtoJs(), "AndroidtoJs");
        mWebView.loadUrl(url);
        showDialog();
        setWeb(mWebView);
        mWebView.setWebChromeClient(new PQChromeClient());
    }


    //    @Receive(Events.JS_OPEN_CLOSE_WEB)
    //    public void fin() {
    //        finish();
    //    }


    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == 101 && mUploadMessage != null) {
            try {
                String file_path = mCameraPhotoPath.replace("file:", "");
                File file = new File(file_path);
                size = file.length();
                if (!(data != null || size > 0)) {
                    mUploadMessage.onReceiveValue(null);
                    mUploadMessage = null;
                    return;
                }
                if (data != null || mCameraPhotoPath != null) {
                    Integer count = 1;
                    ClipData images = null;
                    try {
                        images = data.getClipData();
                    } catch (Exception e) {
                        Log.e("Error11!", e.getLocalizedMessage());
                    }
                    if (images == null && data != null && data.getDataString() != null) {
                        count = data.getDataString().length();
                    } else if (images != null) {
                        count = images.getItemCount();
                    }
                    Uri[] results = new Uri[count];
                    // Check that the response is a good one
                    if (resultCode == Activity.RESULT_OK) {
                        if (size != 0) {
                            // If there is not data, then we may have taken a photo
                            if (mCameraPhotoPath != null) {
                                results = new Uri[]{Uri.parse(mCameraPhotoPath)};
                            }
                        } else if (data.getClipData() == null) {
                            results = new Uri[]{Uri.parse(data.getDataString())};
                        } else {
                            for (int i = 0; i < images.getItemCount(); i++) {
                                results[i] = images.getItemAt(i).getUri();
                            }
                        }
                    }
                    mUploadMessage.onReceiveValue(results);
                    mUploadMessage = null;
                }
            } catch (Exception e) {
                Log.e("Error22!", "Error while opening image file" + e.getLocalizedMessage());
            }
        }
    }

    public class PQChromeClient extends WebChromeClient {
        // For Android 5.0+
        public boolean onShowFileChooser(WebView view, ValueCallback<Uri[]> filePath, WebChromeClient.FileChooserParams fileChooserParams) {
            L.e("点击》》", "11");
            // Double check that we don't have any existing callbacks
            if (mUploadMessage != null) {
                L.e("点击》》", "22");
                mUploadMessage.onReceiveValue(null);
            }
            mUploadMessage = filePath;
            Log.e("FileCooserParams => ", filePath.toString());
            Intent takePictureIntent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
            if (takePictureIntent.resolveActivity(getPackageManager()) != null) {
                // Create the File where the photo should go
                File photoFile = null;
                try {
                    photoFile = createImageFile();
                    takePictureIntent.putExtra("PhotoPath", mCameraPhotoPath);
                } catch (IOException ex) {
                    // Error occurred while creating the File
                    Log.e("test", "Unable to create Image File", ex);
                }
                // Continue only if the File was successfully created
                if (photoFile != null) {
                    mCameraPhotoPath = "file:" + photoFile.getAbsolutePath();
                    takePictureIntent.putExtra(MediaStore.EXTRA_OUTPUT, Uri.fromFile(photoFile));
                } else {
                    takePictureIntent = null;
                }
            }

            Intent contentSelectionIntent = new Intent(Intent.ACTION_GET_CONTENT);
            contentSelectionIntent.addCategory(Intent.CATEGORY_OPENABLE);
            contentSelectionIntent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true);
            contentSelectionIntent.setType("image/*");
            Intent[] intentArray;
            if (takePictureIntent != null) {
                intentArray = new Intent[]{takePictureIntent};
            } else {
                intentArray = new Intent[2];
            }
            Intent chooserIntent = new Intent(Intent.ACTION_CHOOSER);
            chooserIntent.putExtra(Intent.EXTRA_INTENT, contentSelectionIntent);
            chooserIntent.putExtra(Intent.EXTRA_TITLE, "Image Chooser");
            chooserIntent.putExtra(Intent.EXTRA_INITIAL_INTENTS, intentArray);
            startActivityForResult(Intent.createChooser(chooserIntent, "Select images"), 101);
            return true;
        }
    }

    private File createImageFile() throws IOException {
        // Create an image file name
        String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
        String imageFileName = "JPEG_" + timeStamp + "_";
        File storageDir = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES);
        File imageFile = File.createTempFile(imageFileName,  /* prefix */
                ".jpg",         /* suffix */
                storageDir      /* directory */);
        return imageFile;
    }

}